# libpythonpro
Módulo para exemplificar construção de projetos Python no módulo PyTools.

Nesse módulo, é ensinado como contribuir com projetos de código aberto.

Link para o curso [Dev Pro](https://plataforma.dev.pro.br/)

Suportada versão 3 de Python.

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip 